summaryrefslogtreecommitdiff
path: root/taler_wallet_core_lib.h
diff options
context:
space:
mode:
authorFlorian Dold <florian@dold.me>2023-01-04 11:23:39 +0100
committerFlorian Dold <florian@dold.me>2023-01-04 11:23:39 +0100
commit57535d3ed1847ec3335ab2b86a313a972da54688 (patch)
treee2aa5db31121734d4f76f1341da162e716a37065 /taler_wallet_core_lib.h
parent2e947cccfc3f7b9b496906051a7ed300c01aefdf (diff)
downloadquickjs-tart-57535d3ed1847ec3335ab2b86a313a972da54688.tar.gz
quickjs-tart-57535d3ed1847ec3335ab2b86a313a972da54688.tar.bz2
quickjs-tart-57535d3ed1847ec3335ab2b86a313a972da54688.zip
implement Marc's naming suggestions
Diffstat (limited to 'taler_wallet_core_lib.h')
-rw-r--r--taler_wallet_core_lib.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/taler_wallet_core_lib.h b/taler_wallet_core_lib.h
index 6dc92af..97b9d50 100644
--- a/taler_wallet_core_lib.h
+++ b/taler_wallet_core_lib.h
@@ -28,7 +28,7 @@
/**
* Opaque handle to a Taler wallet-core.
*/
-struct TALER_WALLET_Handle;
+struct TALER_WALLET_Instance;
/**
* Handler for messages from the wallet.
@@ -39,9 +39,9 @@ struct TALER_WALLET_Handle;
typedef void (*TALER_WALLET_MessageHandlerFn)(void *handler_p, const char *message);
/**
* Create a new wallet-core handle.
*/
-struct TALER_WALLET_Handle *
+struct TALER_WALLET_Instance *
TALER_WALLET_create(void);
/**
@@ -51,9 +51,9 @@ TALER_WALLET_create(void);
* Caution: The handler will be called from a different thread.
*/
void
-TALER_WALLET_set_handler(struct TALER_WALLET_Handle *h,
- TALER_WALLET_MessageHandlerFn handler_f,
- void *handler_p);
+TALER_WALLET_set_message_handler(struct TALER_WALLET_Instance *h,
+ TALER_WALLET_MessageHandlerFn handler_f,
+ void *handler_p);
/**
@@ -62,17 +62,17 @@ TALER_WALLET_set_handler(struct TALER_WALLET_Handle *h,
*/
// FIXME: Not implemented!
//void
-//TALER_WALLET_set_jsfile(struct TALER_WALLET_Handle *h,
+//TALER_WALLET_set_jsfile(struct TALER_WALLET_Instance *h,
// const char *filename);
/**
* Send a message to wallet-core.
*
* Responses will be sent asynchronously to the message handler
- * set with #TALER_WALLET_set_handler.
+ * set with #TALER_WALLET_set_message_handler.
*/
int
-TALER_WALLET_send_message(struct TALER_WALLET_Handle *h,
+TALER_WALLET_send_request(struct TALER_WALLET_Instance *h,
const char *msg);
/**
@@ -81,13 +81,13 @@ TALER_WALLET_send_message(struct TALER_WALLET_Handle *h,
* This function creates a new thread and returns immediately.
*/
void
-TALER_WALLET_run(struct TALER_WALLET_Handle *h);
+TALER_WALLET_run(struct TALER_WALLET_Instance *h);
/**
* Block until the wallet returns.
*/
void
-TALER_WALLET_join(struct TALER_WALLET_Handle *wh);
+TALER_WALLET_join(struct TALER_WALLET_Instance *wh);
/**
* Destroy the wallet handle and free resources associated with it.
@@ -98,6 +98,6 @@ TALER_WALLET_join(struct TALER_WALLET_Handle *wh);
* sent a response to the shutdown message.
*/
void
-TALER_WALLET_destroy(struct TALER_WALLET_Handle *h);
+TALER_WALLET_destroy(struct TALER_WALLET_Instance *h);
#endif /*_TALER_WALLET_LIB_H */
@@ -39,9 +39,9 @@ struct TALER_WALLET_Handle;
typedef void (*TALER_WALLET_MessageHandlerFn)(void *handler_p, const char *message);
/**
- * Create a new wallet-core handle.
+ * Create a new wallet-core instance..
*/